/*
  Xinvest Copyright (c)1997,2000 
  Mark Buser, All Rights Reserved.

  Permission is hereby granted to copy
  and freely distribute copies of this
  program for non-commercial purposes
  without fee, provided that this notice
  appears in all copies.
  
  All redistributions must be in their
  entirety as originally distributed.
  Feel free to modify Xinvest, but
  modified versions may not be distributed
  without prior consent of the author.
  
  This software is provided 'as-is'
  without any express or implied warranty.
  In no event will the author be held
  liable for any damages resulting from
  the use of this software.

  $Revision: 1.3 $ $Date: 2000/01/11 22:19:26 $
*/
#ifndef report_h
#define report_h

/* Report initialization */
void reportInit (Widget, char *);

/* Report refresh */
void displayReport (int);

/* Report callbacks */
void reportSetTime ();
void reportSetValue ();
void reportSetAccount ();
void reportCustomTime ();
void reportGenerate ();

#endif
